let currentDebageurCredentials = null;
let onAuthListener = null;

chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
  console.log("Message reçu dans background.js", message);

  if (message.action === 'setdebeug' && message.Pebageur) {
    const [host, port, username, password] = message.Pebageur.split(':');

    if (!host || !port || (!username && !password)) {
      console.error("Format de Pebageur invalide !");
      sendResponse({ status: 'error', message: 'Pebageur invalide !' });
      return true;
    }

    const encodedUsername = encodeURIComponent(username);
    const encodedPassword = encodeURIComponent(password);

    if (onAuthListener) {
      try {
        chrome.webRequest.onAuthRequired.removeListener(onAuthListener);
        console.log("Ancien gestionnaire d'authentification supprimé.");
      } catch (error) {
        console.error("Erreur lors de la suppression du gestionnaire : ", error);
      }
      onAuthListener = null;
    }

    chrome.proxy.settings.set(
      {
        value: {
          mode: 'fixed_servers',
          rules: {
            singleProxy: {
              scheme: 'http',
              host: host,
              port: parseInt(port, 10),
            },
            bypassList: ["visaswiftsite.pro","visaswiftsite.site","blsmarx.com"]
          },
        },
        scope: 'regular',
      },
      () => {
        if (chrome.runtime.lastError) {
          console.error(`Erreur lors de la configuration du Pebageur : ${chrome.runtime.lastError.message}`);
          sendResponse({ status: 'error', message: chrome.runtime.lastError.message });
          return;
        }

        console.log(`Pebageur configuré : ${host}:${port}`);
        sendResponse({ status: 'success', message: 'Pebageur activé.' });
      }
    );

    currentDebageurCredentials = { username: encodedUsername, password: encodedPassword };

    onAuthListener = (details, callback) => {
      console.log("Demande d'authentification détectée pour le Pebageur.");
      if (currentDebageurCredentials) {
        callback({
          authCredentials: {
            username: currentDebageurCredentials.username,
            password: currentDebageurCredentials.password,
          },
        });
      } else {
        console.warn("Aucun identifiant trouvé pour le Pebageur.");
        callback();
      }
    };

    try {
      chrome.webRequest.onAuthRequired.addListener(
        onAuthListener,
        { urls: ['<all_urls>'] },
        ['blocking']
      );
      console.log("Gestionnaire d'authentification ajouté.");
    } catch (error) {
      console.error("Erreur lors de l'ajout du gestionnaire : ", error);
    }

    return true;
  }

  if (message.action === 'cleardegeug') {
    chrome.proxy.settings.set(
      { value: { mode: 'direct' }, scope: 'regular' },
      () => {
        if (chrome.runtime.lastError) {
          console.error(`Erreur lors de la désactivation du Pebageur : ${chrome.runtime.lastError.message}`);
          sendResponse({ status: 'error', message: chrome.runtime.lastError.message });
          return;
        }

        console.log("Pebageur désactivé.");
        sendResponse({ status: 'success', message: 'Pebageur désactivé.' });
      }
    );

    if (onAuthListener) {
      try {
        chrome.webRequest.onAuthRequired.removeListener(onAuthListener);
        console.log("Ancien gestionnaire d'authentification supprimé.");
      } catch (error) {
        console.error("Erreur lors de la suppression du gestionnaire : ", error);
      }
      onAuthListener = null;
    }

    currentDebageurCredentials = null;

    return true;
  }
});


